==============
Image to LaTeX
==============


.. image:: https://img.shields.io/pypi/v/imglatex.svg
        :target: https://pypi.python.org/pypi/imglatex

.. image:: https://img.shields.io/travis/odarbelaeze/imglatex.svg
        :target: https://travis-ci.org/odarbelaeze/imglatex

.. image:: https://readthedocs.org/projects/imglatex/badge/?version=latest
        :target: https://imglatex.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status


.. image:: https://pyup.io/repos/github/odarbelaeze/imglatex/shield.svg
     :target: https://pyup.io/repos/github/odarbelaeze/imglatex/
     :alt: Updates



Turns a folder full of images into a LaTeX file that contains them as figures with captions.


* Free software: MIT license
* Documentation: https://imglatex.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
